ExoTiC-LD
===========

**Calculate limb-darkening coefficients for specific instruments, stars, and wavelength ranges.**

.. image:: https://github.com/DavoGrant/ExoTiC-MIRI/workflows/unittests/badge.svg
   :target: https://github.com/DavoGrant/ExoTiC-MIRI/actions/workflows/python-app.yml
   
.. image:: https://readthedocs.org/projects/exotic-ld/badge/?version=latest
   :target: https://exotic-ld.readthedocs.io/en/latest/?badge=latest

|

::

   pip install exotic-ld

| Read the full documentation at: `exotic-ld.readthedocs.io <https://exotic-ld.readthedocs.io/>`_
